@@ -3,13 +3,12 @@ from __future__ import annotations
 from typing import (
   AsyncIterable,
   Coroutine,
-  Optional,
   Union,
 )
 
 from .rajapinta import Rajapinta
 from .sivutus import SivutettuHaku
-from .tyokalut import luokkamaare
+from .tyokalut import ei_syotetty, luokkamaare, Valinnainen
 from .yhteys import AsynkroninenYhteys
 
 
@@ -39,7 +38,7 @@ class RestYhteys(SivutettuHaku, AsynkroninenYhteys):
 
     def nouda(
       self,
-      pk: Optional[Union[str, int]] = None,
+      pk: Valinnainen[Union[str, int]] = ei_syotetty,
       **params
     ) -> Union[Coroutine, AsyncIterable[Rajapinta.Tuloste]]:
       '''
@@ -49,7 +48,7 @@ class RestYhteys(SivutettuHaku, AsynkroninenYhteys):
       (`kwargs`) täsmäävien tietueiden hakemiseksi.
       '''
       # pylint: disable=invalid-overridden-method, no-member
-      if pk is not None:
+      if pk is not ei_syotetty:
         return super().nouda(pk=pk, **params)
 
       async def _nouda():
